============
Installation
============

To install, with the command line::

    pip install ngoschema

Settings are managed using
`simple-settings <https://github.com/drgarcia1986/simple-settings>`_
and can be overriden with configuration files (cfg, yaml, json) or with environment variables
prefixed with ``NGOSCHEMA_``.
